@@ -1,4 +1,5 @@
 WIDTH = 600
 HEIGHT = 800
-TITLE = 'Youtube Downloader'
+TITLE = 'ytdl_gui'
 APPID = 'org.sheep.youtube-downloader'
+CSSPATH = 'ytdl_gui/css/style.css'
