@@ -2,12 +2,12 @@ import re
 import threading
 from yt_dlp import YoutubeDL
 import yt_dlp
-import hashlib, base64
 
 class YTDL_Controller():
     def __init__(self, window):
         self.ydl_opts = {
             'logger': self.Logger(),
+            'nocheckcertificate': True,
         }
         self.window = window
 
@@ -45,4 +45,3 @@ def validate_link(url: str):
 def convert_link(url: str):
     id: str = re.search(r"(?:\?v=|v\/|embed\/|youtu\.be\/)([\w\-]+)", url).group(1)
     return id
-    print(id)
